<template>
  <el-card shadow="never" class="aui-card--fill">
    <div class="mod-app">
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <span>统计日期：</span>
          <el-date-picker
              v-model="dataForm.rq"
              type="date"
              :clearable="true"
              value-format="yyyy-MM-dd"
              placeholder="日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item>
          <el-button @click="getDataList()">{{ $t('query') }}</el-button>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" @click="openForm()">{{ $t('add') }}</el-button>
        </el-form-item>
        <el-form-item>
          <el-button @click="exportExcel()">导出</el-button>
        </el-form-item>
        <div style="float: right">
          <el-form-item>
            <span>月初：</span>
            <el-date-picker
                v-model="dataForm.monthStart"
                type="date"
                readonly
                value-format="yyyy-MM-dd">
            </el-date-picker>
          </el-form-item>
          <el-form-item>
            <span>年初：</span>
            <el-date-picker
                v-model="dataForm.yearStart"
                type="date"
                readonly
                value-format="yyyy-MM-dd">
            </el-date-picker>
          </el-form-item>
        </div>
      </el-form>
      <el-table
          ref="table"
          v-loading="dataListLoading"
          :data="dataList"
          border
          style="width: 100%;">
        <el-table-column type="index" header-align="center" align="center" min-width="50" label="序号"></el-table-column>
        <el-table-column prop="lsh" header-align="center" align="center" label="流水号" min-width="200"></el-table-column>
        <el-table-column prop="rq" header-align="center" align="center" label="日期" min-width="120"></el-table-column>
        <el-table-column prop="bcName" header-align="center" align="center" label="班次" min-width="100"></el-table-column>
        <el-table-column prop="mcName" header-align="center" align="center" label="煤仓" min-width="100"></el-table-column>
        <el-table-column prop="crl" header-align="center" align="center" label="仓容量" min-width="100"></el-table-column>
        <el-table-column prop="cpName" header-align="center" align="center" label="产品" min-width="100"></el-table-column>
        <el-table-column header-align="center" align="center" label="内报量">
          <el-table-column prop="nbgl" header-align="center" align="center" label="仓存估量(t)" min-width="160">
            <template slot-scope="scope">
              <span style="color: red">{{scope.row.nbgl}}</span>
            </template>
          </el-table-column>
        </el-table-column>
        <el-table-column header-align="center" align="center" label="外报量">
          <el-table-column prop="wbgl" header-align="center" align="center" label="仓存估量(t)" min-width="160">
            <template slot-scope="scope">
              <span style="color: red">{{scope.row.wbgl}}</span>
            </template>
          </el-table-column>
        </el-table-column>
        <el-table-column show-overflow-tooltip prop="bz" header-align="center" align="center" label="备注" min-width="200"></el-table-column>
        <el-table-column :label="$t('handle')" fixed="right" header-align="center" align="center" min-width="100">
          <template slot-scope="scope">
            <el-button type="text" size="small" @click="openForm(scope.row.id)">修改</el-button>
            <el-button type="text" size="small" @click="handleDelete(scope.row.id)">删除</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination
          :current-page="page"
          :page-sizes="[10, 20, 50, 100]"
          :page-size="limit"
          :total="total"
          layout="total, sizes, prev, pager, next, jumper"
          @size-change="pageSizeChangeHandle"
          @current-change="pageCurrentChangeHandle">
      </el-pagination>
      <!-- 弹窗, 新增 / 修改 -->
      <add-or-update v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></add-or-update>
    </div>
  </el-card>
</template>

<script>
import mixinViewModule from '@/mixins/view-module'
import AddOrUpdate from './list-add-or-update'
import {exportByDom} from "@/utils/exportUtil";
export default {
  mixins: [mixinViewModule],
  data () {
    return {
      mixinViewModuleOptions: {
        getDataListURL: '/iailab-iems-coal-proddisp/warehouse/position/list',
        getDataListIsPage: true,
        deleteURL: '/iailab-iems-coal-proddisp/warehouse/position',
        deleteIsBatch: true,
      },
      dataForm: {
        rq: (new Date()).Format('yyyy-MM-dd'),
        monthStart: '',
        yearStart: ''
      },
      statisticsList: []
    }
  },
  components: {
    AddOrUpdate
  },
  created () {
    if (this.mixinViewModuleOptions.createdIsNeed) {
      this.query()
      this.getDate()
    }
  },
  methods: {
    getDataList: function () {
      this.page = 1
      this.query()
      this.getDate()
    },
    getDate () {
      this.$http.get(
          '/iailab-iems-coal-proddisp/warehouse/position/date').then(({ data: res }) => {
        if (res.code !== 0) {
          return this.$message.error(res.msg)
        }
        this.dataForm.monthStart = res.monthStart
        this.dataForm.yearStart = res.yearStart
      }).catch(() => {})
    },
    exportExcel () {
      let dom = this.$refs.table
      exportByDom(dom, undefined, '仓位统计')
    }
  }
}
</script>

<style scoped>

/deep/ .el-table__footer-wrapper tbody td,
.el-table__header-wrapper tbody td {
  background-color: #e3f3ff !important;
}
/deep/ .el-table__footer-wrapper .is-leaf {
  background-color: #e3f3ff !important;
}
/deep/ .el-table__fixed-footer-wrapper tbody td {
  border-top: 1px solid #ebeef5;
  background-color: #e3f3ff;
  font-weight: bold;
  color: #f50b0b;
  text-align: center !important;
}
/deep/ .has-gutter tr td .cell {
  text-align: center;
  font-weight: bold;
  color: blue;
}
</style>
